<?php
namespace Drupal\private_message_invite\Controller;

use Drupal\private_message_invite\Entity\private_message_invite;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\HttpFoundation\Request;
use Drupal\Core\Access\AccessResult;
use Drupal\Core\Url;
use Drupal\Core\Controller\ControllerBase;

class PrivateMessageInviteController extends ControllerBase{

  /**
  * Invite Email Configuration form Rendering.
  */
  public function configPage() {
      return [
          'form' => \Drupal::formBuilder()->getForm('Drupal\private_message_invite\Form\ConfigForm'),
      ];
  }

  /**
  * Invite Email Accept.
  */
  public function accept(Request $request, private_message_invite $private_message_invite) {
    $invited = $private_message_invite->get('invite_uid')->entity;
    $private_message_invite->set('invite_status',private_message_invite::ACCEPT); 
    $private_message_invite->save();
    $message_thread = $private_message_invite->get('pm_thread')->entity;
    $members = $message_thread->get('members')->getValue();
    $members[count($members)]['target_id'] = $invited->id();
    $message_thread->set('members',$members); 
    $message_thread->save();
    \Drupal::messenger()->addStatus($this->t('You have accepted the invitation.'));
    $url = Url::fromRoute('entity.private_message_thread.canonical', ['private_message_thread' => $message_thread->id()], ['absolute' => TRUE]);
    $response = new RedirectResponse($url->toString());
    $response->send();
    return;
  }
    
  /**
  * Invite Email Decline.
  */
  public function decline(Request $request, private_message_invite $private_message_invite) {
    $private_message_invite->delete();
    \Drupal::messenger()->addStatus($this->t('You have Rejected the invitation.'));
    $url = Url::fromRoute('user.page', [], ['absolute' => 'true']);
    $response = new RedirectResponse($url->toString());
    $response->send();
    return;
  }

  /**
  * Invite Email Access check.
  */
  public function checkAccess(private_message_invite $private_message_invite) {
    $currentUser = \Drupal::currentUser();
    $invited = $private_message_invite->get('invite_uid')->entity;
    $entity = $private_message_invite->get('pm_thread')->entity;
    $membership = $entity->isMember($currentUser->id());

    // Only allow user accept/decline own invitations.
    if ($invited->id() == $currentUser->id() && !$membership) {
      return AccessResult::allowed();
    }
    return AccessResult::forbidden();
  }
}